@@ -1210,7 +1210,7 @@ make_nyi_page (QueryDruid *qdruid)
 	vbox = GNOME_DRUID_PAGE_STANDARD (wid)->vbox;
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 16);
 
-	str = g_strdup_printf ("<b>%s</b>", _("This functionnality is not yet implemented"));
+	str = g_strdup_printf ("<b>%s</b>", _("This functionality is not yet implemented"));
 	wid = gtk_label_new (str);
 	g_free (str);
 	gtk_widget_show (wid);
