@@ -49,7 +49,7 @@ struct _QueryEditorPriv
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
-guint
+GType
 query_editor_get_type (void)
 {
 	static GType type = 0;
