@@ -60,7 +60,7 @@ struct _WsDatatypesPrivate
 	GObject        *sel_obj;
 };
 
-guint
+GType
 ws_datatypes_get_type (void)
 {
 	static GType type = 0;
